@@ -1,24 +1,37 @@
-/***************************************************************************
- *   Copyright (C) 2006 by Felix Hammer   *
- *   f.hammer@web.de   *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+/*****************************************************************************
+ * PokerTH - The open source texas holdem engine                             *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
+ *                                                                           *
+ * This program is free software: you can redistribute it and/or modify      *
+ * it under the terms of the GNU Affero General Public License as            *
+ * published by the Free Software Foundation, either version 3 of the        *
+ * License, or (at your option) any later version.                           *
+ *                                                                           *
+ * This program is distributed in the hope that it will be useful,           *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU Affero General Public License for more details.                       *
+ *                                                                           *
+ * You should have received a copy of the GNU Affero General Public License  *
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
+ *****************************************************************************/
 #include "cleanerconfig.h"
-#include "tinyxml.h"
+#include <QtCore>
+
+#include <tinyxml.h>
 
 #define MODUS 0711
 
@@ -35,23 +48,20 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#include <QtCore>
-
 using namespace std;
 
 
 CleanerConfig::CleanerConfig()
 {
 	// !!!! Revisionsnummer der Configdefaults !!!!!
-        configRev = 8;
-	
+	configRev = 10;
+
 	// Pfad und Dateinamen setzen
 #ifdef _WIN32
 	const char *appDataPath = getenv("AppData");
 	if (appDataPath && appDataPath[0] != 0) {
-		configFileName = appDataPath; 
-	}
-	else {
+		configFileName = appDataPath;
+	} else {
 		const int MaxPathSize = 1024;
 		char curDir[MaxPathSize + 1];
 		curDir[0] = 0;
@@ -67,8 +77,7 @@ CleanerConfig::CleanerConfig()
 			// Datei wieder loeschen.
 			tmpFile.close();
 			remove((configFileName + "\\" + tmpFileName).c_str());
-		}
-		else {
+		} else {
 			// Fehlgeschlagen, Verzeichnis nicht beschreibbar
 			curDir[0] = 0;
 			GetTempPathA(MaxPathSize, curDir);
@@ -81,12 +90,12 @@ CleanerConfig::CleanerConfig()
 	////define log-dir
 // 	logDir = configFileName;
 // 	logDir += "log-files\\";
-	
+
 	//create directories on first start of app
 	mkdir(configFileName.c_str());
 // 	mkdir(logDir.c_str());
-	
-		
+
+
 #else
 	//define app-dir
 	const char *homePath = getenv("HOME");
@@ -99,12 +108,10 @@ CleanerConfig::CleanerConfig()
 		//create directories on first start of app
 		mkdir(configFileName.c_str(), MODUS) ;
 // 		mkdir(logDir.c_str(), MODUS);
-	
-	}
-	
-#endif
 
-	string userDir = configFileName.c_str();
+	}
+
+#endif
 
 	ostringstream tempIntToString;
 	tempIntToString << configRev;
@@ -116,15 +123,15 @@ CleanerConfig::CleanerConfig()
 	configList.push_back(ConfigInfo("DefaultListenPort", CONFIG_TYPE_STRING, "4327"));
 	configList.push_back(ConfigInfo("ClientAuthString", CONFIG_TYPE_STRING, ""));
 	configList.push_back(ConfigInfo("ServerAuthString", CONFIG_TYPE_STRING, ""));
-	
+
 	configList.push_back(ConfigInfo("WarnLevelToKick", CONFIG_TYPE_INT, "2"));
 	configList.push_back(ConfigInfo("TextFloodLevelToTrigger", CONFIG_TYPE_INT, "3"));
 	configList.push_back(ConfigInfo("CapsFloodCapsNumberToTrigger", CONFIG_TYPE_INT, "10"));
 	configList.push_back(ConfigInfo("LetterRepeatingNumberToTrigger", CONFIG_TYPE_INT, "10"));
 
-        configList.push_back(ConfigInfo("KickNumberToBan", CONFIG_TYPE_INT, "2"));
-        configList.push_back(ConfigInfo("SecondsToForgetAboutKick", CONFIG_TYPE_INT, "1800"));
-	
+	configList.push_back(ConfigInfo("KickNumberToBan", CONFIG_TYPE_INT, "2"));
+	configList.push_back(ConfigInfo("SecondsToForgetAboutKick", CONFIG_TYPE_INT, "1800"));
+
 	list<string> badWordsList;
 	badWordsList.push_back("arsch");
 	badWordsList.push_back("asshole");
@@ -142,6 +149,7 @@ CleanerConfig::CleanerConfig()
 	badWordsList.push_back("gay");
 	badWordsList.push_back("horny");
 	badWordsList.push_back("hure");
+	badWordsList.push_back("idiot");
 	badWordsList.push_back("mistgeburt");
 	badWordsList.push_back("missgeburt");
 	badWordsList.push_back("motherfucker");
@@ -162,6 +170,15 @@ CleanerConfig::CleanerConfig()
 	badWordsList.push_back("whore");
 	configList.push_back(ConfigInfo("BadWordsList", CONFIG_TYPE_STRING_LIST, "BadWords", badWordsList));
 
+	list<string> badWordsExceptionList;
+	badWordsExceptionList.push_back("idiots end");
+	badWordsExceptionList.push_back("all-in-idiot");
+	badWordsExceptionList.push_back("all-in idiot");
+	badWordsExceptionList.push_back("allin idiot");
+	badWordsExceptionList.push_back("all in idiot");
+	configList.push_back(ConfigInfo("BadWordsException", CONFIG_TYPE_STRING_LIST, "BadWordsException", badWordsExceptionList));
+
+
 	list<string> urlStringsList;
 	urlStringsList.push_back("http://");
 	urlStringsList.push_back(".com");
@@ -169,38 +186,39 @@ CleanerConfig::CleanerConfig()
 	urlStringsList.push_back(".org");
 	urlStringsList.push_back(".de");
 	configList.push_back(ConfigInfo("UrlStringsList", CONFIG_TYPE_STRING_LIST, "UrlStrings", urlStringsList));
-	
+
 	list<string> urlExceptionStringsList;
 	urlExceptionStringsList.push_back("http://www.esl.");
 	urlExceptionStringsList.push_back("http://www.pokerth.net");
 	urlExceptionStringsList.push_back("pokerth.net");
 	configList.push_back(ConfigInfo("UrlExceptionStringsList", CONFIG_TYPE_STRING_LIST, "UrlExceptionStrings", urlExceptionStringsList));
-	
+
 	//fill tempList firstTime
 	configBufferList = configList;
 
 	configFileName += "cleanerconfig.xml";
-	
-	//Prüfen ob Configfile existiert --> sonst anlegen
-	TiXmlDocument doc(configFileName); 
-	if(!doc.LoadFile()){ 
-		myConfigState = NONEXISTING;
-		updateConfig(myConfigState); 
-	}
-	else { 
-	//Check if config revision is ok. Otherwise --> update()
-		int tempRevision = 0;
-		
-		TiXmlHandle docHandle( &doc );		
-		TiXmlElement* confRevision = docHandle.FirstChild( "PokerTHCleaner" ).FirstChild( "Configuration" ).FirstChild( "ConfigRevision" ).ToElement();
-		if ( confRevision ) { confRevision->QueryIntAttribute("value", &tempRevision ); }
 
-		if (tempRevision < configRev ) { /*löschen()*/ 
+	//Prüfen ob Configfile existiert --> sonst anlegen
+	TiXmlDocument doc(configFileName);
+	if(!doc.LoadFile()) {
+		myConfigState = NONEXISTING;
+		updateConfig(myConfigState);
+	} else {
+		//Check if config revision is ok. Otherwise --> update()
+		int tempRevision = 0;
+
+		TiXmlHandle docHandle( &doc );
+		TiXmlElement* confRevision = docHandle.FirstChild( "PokerTHCleaner" ).FirstChild( "Configuration" ).FirstChild( "ConfigRevision" ).ToElement();
+		if ( confRevision ) {
+			confRevision->QueryIntAttribute("value", &tempRevision );
+		}
+
+		if (tempRevision < configRev ) { /*löschen()*/
 			myConfigState = OLD;
 			updateConfig(myConfigState) ;
 		}
 	}
-	
+
 
 	fillBuffer();
 }
@@ -211,20 +229,21 @@ CleanerConfig::~CleanerConfig()
 }
 
 
-void CleanerConfig::fillBuffer() {
+void CleanerConfig::fillBuffer()
+{
 
 	string tempString1("");
 	string tempString2("");
 
-	TiXmlDocument doc(configFileName); 
-		
+	TiXmlDocument doc(configFileName);
+
 	if(doc.LoadFile()) {
-	TiXmlHandle docHandle( &doc );	
+		TiXmlHandle docHandle( &doc );
 
 		for (size_t i=0; i<configBufferList.size(); i++) {
-	
+
 			TiXmlElement* conf = docHandle.FirstChild( "PokerTHCleaner" ).FirstChild( "Configuration" ).FirstChild( configList[i].name ).ToElement();
-				
+
 			if ( conf ) {
 
 				const char *tmpStr1 = conf->Attribute("value");
@@ -233,38 +252,40 @@ void CleanerConfig::fillBuffer() {
 
 				const char *tmpStr2 = conf->Attribute("type");
 				if (tmpStr2) {
-					tempString2 = tmpStr2; 
+					tempString2 = tmpStr2;
 					if(tempString2 == "list") {
-				
+
 						list<string> tempStringList2;
 
 						TiXmlElement* confList = docHandle.FirstChild( "PokerTHCleaner" ).FirstChild( "Configuration" ).FirstChild( configList[i].name ).FirstChild().ToElement();
-						
+
 						for( ; confList; confList=confList->NextSiblingElement()) {
 							tempStringList2.push_back(confList->Attribute("value"));
 						}
-						
+
 						configBufferList[i].defaultListValue = tempStringList2;
 					}
 				}
-			}	
-			else { qDebug("Could not find the root element in the config file!"); }
+			} else {
+				qDebug("Could not find the root element in the config file!");
+			}
 		}
 	}
 }
 
-void CleanerConfig::writeBuffer() const {
+void CleanerConfig::writeBuffer() const
+{
+
+	TiXmlDocument doc;
+	TiXmlDeclaration * decl = new TiXmlDeclaration( "1.0", "UTF-8", "");
+	doc.LinkEndChild( decl );
+
+	TiXmlElement * root = new TiXmlElement( "PokerTHCleaner" );
+	doc.LinkEndChild( root );
 
-	TiXmlDocument doc;  
-	TiXmlDeclaration * decl = new TiXmlDeclaration( "1.0", "UTF-8", ""); 
-	doc.LinkEndChild( decl );  
-		
-	TiXmlElement * root = new TiXmlElement( "PokerTHCleaner" );  
-	doc.LinkEndChild( root );  		
-		
 	TiXmlElement * config;
-	config = new TiXmlElement( "Configuration" );  
-	root->LinkEndChild( config );  
+	config = new TiXmlElement( "Configuration" );
+	root->LinkEndChild( config );
 
 	size_t i;
 
@@ -272,42 +293,43 @@ void CleanerConfig::writeBuffer() const {
 		TiXmlElement *tmpElement = new TiXmlElement(configBufferList[i].name);
 		config->LinkEndChild( tmpElement );
 		tmpElement->SetAttribute("value", configBufferList[i].defaultValue);
-	
+
 		if(configBufferList[i].type == CONFIG_TYPE_INT_LIST || configBufferList[i].type == CONFIG_TYPE_STRING_LIST) {
 
 			tmpElement->SetAttribute("type", "list");
 			list<string> tempList = configBufferList[i].defaultListValue;
 			list<string>::iterator it;
-			for(it = tempList.begin(); it != tempList.end(); it++) {
-		
+			for(it = tempList.begin(); it != tempList.end(); ++it) {
+
 				TiXmlElement *tmpSubElement = new TiXmlElement(configBufferList[i].defaultValue);
 				tmpElement->LinkEndChild( tmpSubElement );
 				tmpSubElement->SetAttribute("value", *it);
 			}
 
 		}
-	}	
+	}
 	doc.SaveFile( configFileName );
 
 }
 
-void CleanerConfig::updateConfig(ConfigState myConfigState) {
+void CleanerConfig::updateConfig(ConfigState myConfigState)
+{
 
 	size_t i;
-	
+
 	if(myConfigState == NONEXISTING) {
-		
+
 		//Create a new ConfigFile!
-		TiXmlDocument doc;  
-		TiXmlDeclaration * decl = new TiXmlDeclaration( "1.0", "UTF-8", ""); 
-		doc.LinkEndChild( decl );  
-		
-		TiXmlElement * root = new TiXmlElement( "PokerTHCleaner" );  
-		doc.LinkEndChild( root );  		
-		
+		TiXmlDocument doc;
+		TiXmlDeclaration * decl = new TiXmlDeclaration( "1.0", "UTF-8", "");
+		doc.LinkEndChild( decl );
+
+		TiXmlElement * root = new TiXmlElement( "PokerTHCleaner" );
+		doc.LinkEndChild( root );
+
 		TiXmlElement * config;
-		config = new TiXmlElement( "Configuration" );  
-		root->LinkEndChild( config );  
+		config = new TiXmlElement( "Configuration" );
+		root->LinkEndChild( config );
 
 		for (i=0; i<configList.size(); i++) {
 			TiXmlElement *tmpElement = new TiXmlElement(configList[i].name);
@@ -319,8 +341,8 @@ void CleanerConfig::updateConfig(ConfigState myConfigState) {
 				tmpElement->SetAttribute("type", "list");
 				list<string> tempList = configList[i].defaultListValue;
 				list<string>::iterator it;
-				for(it = tempList.begin(); it != tempList.end(); it++) {
-			
+				for(it = tempList.begin(); it != tempList.end(); ++it) {
+
 					TiXmlElement *tmpSubElement = new TiXmlElement(configList[i].defaultValue);
 					tmpElement->LinkEndChild( tmpSubElement );
 					tmpSubElement->SetAttribute("value", *it);
@@ -328,77 +350,77 @@ void CleanerConfig::updateConfig(ConfigState myConfigState) {
 
 			}
 		}
-			
+
 		doc.SaveFile( configFileName );
 	}
 
 
 	if(myConfigState == OLD) {
-	
-		TiXmlDocument oldDoc(configFileName); 
-		
+
+		TiXmlDocument oldDoc(configFileName);
+
 		//load the old one
 		if(oldDoc.LoadFile()) {
-			
-			string tempString1("");
-			string tempString2("");			
- 
-			TiXmlDocument newDoc;
-			
-			//Create the new one
-			TiXmlDeclaration * decl = new TiXmlDeclaration( "1.0", "UTF-8", ""); 
-			newDoc.LinkEndChild( decl );  
-				
-			TiXmlElement * root = new TiXmlElement( "PokerTHCleaner" );  
-			newDoc.LinkEndChild( root );  		
-			
-			TiXmlElement * config;
-			config = new TiXmlElement( "Configuration" );  
-			root->LinkEndChild( config ); 
 
-			//change configRev and AppDataPath				
-			TiXmlElement * confElement0 = new TiXmlElement( "ConfigRevision" ); 
+			string tempString1("");
+			string tempString2("");
+
+			TiXmlDocument newDoc;
+
+			//Create the new one
+			TiXmlDeclaration * decl = new TiXmlDeclaration( "1.0", "UTF-8", "");
+			newDoc.LinkEndChild( decl );
+
+			TiXmlElement * root = new TiXmlElement( "PokerTHCleaner" );
+			newDoc.LinkEndChild( root );
+
+			TiXmlElement * config;
+			config = new TiXmlElement( "Configuration" );
+			root->LinkEndChild( config );
+
+			//change configRev and AppDataPath
+			TiXmlElement * confElement0 = new TiXmlElement( "ConfigRevision" );
 			config->LinkEndChild( confElement0 );
 			confElement0->SetAttribute("value", configRev);
 
-			TiXmlHandle oldDocHandle( &oldDoc );	
+			TiXmlHandle oldDocHandle( &oldDoc );
 
-			for (i=0; i<configList.size(); i++) {	
+			for (i=0; i<configList.size(); i++) {
 
 				TiXmlElement* oldConf = oldDocHandle.FirstChild( "PokerTHCleaner" ).FirstChild( "Configuration" ).FirstChild( configList[i].name ).ToElement();
-				
+
 				if ( oldConf ) {
-				// if element is already there --> take over the saved values
-					
+					// if element is already there --> take over the saved values
+
 					if(configList[i].name != "ConfigRevision") {
-							// dont update ConfigRevision because it was already set ^
-	
+						// dont update ConfigRevision because it was already set ^
+
 						TiXmlElement *tmpElement = new TiXmlElement(configList[i].name);
 						config->LinkEndChild( tmpElement );
-						
+
 						const char *tmpStr1 = oldConf->Attribute("value");
 						if (tmpStr1) tempString1 = tmpStr1;
 						tmpElement->SetAttribute("value", tempString1);
-	
+
 						//for lists copy elements
 						const char *tmpStr2 = oldConf->Attribute("type");
 						if (tmpStr2) {
-							tempString2 = tmpStr2; 
+							tempString2 = tmpStr2;
 							if(tempString2 == "list") {
-					
+
 								list<string> tempStringList2;
-	
+
 								TiXmlElement* oldConfList = oldDocHandle.FirstChild( "PokerTHCleaner" ).FirstChild( "Configuration" ).FirstChild( configList[i].name ).FirstChild().ToElement();
-							
+
 								for( ; oldConfList; oldConfList=oldConfList->NextSiblingElement()) {
 									tempStringList2.push_back(oldConfList->Attribute("value"));
-									}
-								
+								}
+
 								tmpElement->SetAttribute("type", "list");
 								list<string> tempList = tempStringList2;
 								list<string>::iterator it;
-								for(it = tempList.begin(); it != tempList.end(); it++) {
-								
+								for(it = tempList.begin(); it != tempList.end(); ++it) {
+
 									TiXmlElement *tmpSubElement = new TiXmlElement(tempString1);
 									tmpElement->LinkEndChild( tmpSubElement );
 									tmpSubElement->SetAttribute("value", *it);
@@ -406,32 +428,32 @@ void CleanerConfig::updateConfig(ConfigState myConfigState) {
 							}
 						}
 					}
-				}
-				else {
+				} else {
 					// if element is not there --> set it with defaultValue
 					TiXmlElement *tmpElement = new TiXmlElement(configList[i].name);
 					config->LinkEndChild( tmpElement );
 					tmpElement->SetAttribute("value", stringToUtf8(configList[i].defaultValue));
-					
+
 					if(configList[i].type == CONFIG_TYPE_INT_LIST || configList[i].type == CONFIG_TYPE_STRING_LIST) {
-		
+
 						tmpElement->SetAttribute("type", "list");
 						list<string> tempList = configList[i].defaultListValue;
 						list<string>::iterator it;
-						for(it = tempList.begin(); it != tempList.end(); it++) {
-					
+						for(it = tempList.begin(); it != tempList.end(); ++it) {
+
 							TiXmlElement *tmpSubElement = new TiXmlElement(configList[i].defaultValue);
 							tmpElement->LinkEndChild( tmpSubElement );
 							tmpSubElement->SetAttribute("value", *it);
 						}
 					}
 				}
-			}	
+			}
 			newDoc.SaveFile( configFileName );
+		} else {
+			qDebug("Cannot update config file: Unable to load configuration.");
 		}
-		else { qDebug("Cannot update config file: Unable to load configuration."); }
 
-		
+
 	}
 }
 
@@ -441,15 +463,15 @@ string CleanerConfig::readConfigString(string varName) const
 	size_t i;
 	string tempString("");
 
-	for (i=0; i<configBufferList.size(); i++) {	
+	for (i=0; i<configBufferList.size(); i++) {
 
 		if (configBufferList[i].name == varName) {
-			tempString = configBufferList[i].defaultValue;	
+			tempString = configBufferList[i].defaultValue;
 		}
 	}
 
 	return tempString;
- }
+}
 
 int CleanerConfig::readConfigInt(string varName) const
 {
@@ -458,35 +480,35 @@ int CleanerConfig::readConfigInt(string varName) const
 	string tempString("");
 	int tempInt=0;
 
-	for (i=0; i<configBufferList.size(); i++) {	
+	for (i=0; i<configBufferList.size(); i++) {
 
 		if (configBufferList[i].name == varName) {
 			tempString = configBufferList[i].defaultValue;
 		}
 	}
-	
+
 	istringstream isst;
 	isst.str (tempString);
 	isst >> tempInt;
-	
+
 	return tempInt;
 }
 
 list<string> CleanerConfig::readConfigStringList(string varName) const
 {
 
-	size_t i;	
+	size_t i;
 	list<string> tempStringList;
 
-	for (i=0; i<configBufferList.size(); i++) {	
+	for (i=0; i<configBufferList.size(); i++) {
 
 		if (configBufferList[i].name == varName) {
-			tempStringList = configBufferList[i].defaultListValue;	
+			tempStringList = configBufferList[i].defaultListValue;
 		}
 	}
 
 	return tempStringList;
- }
+}
 
 
 list<int> CleanerConfig::readConfigIntList(string varName) const
@@ -496,19 +518,18 @@ list<int> CleanerConfig::readConfigIntList(string varName) const
 	list<string> tempStringList;
 	list<int> tempIntList;
 
-	for (i=0; i<configBufferList.size(); i++) {	
+	for (i=0; i<configBufferList.size(); i++) {
 
 		if (configBufferList[i].name == varName) {
 			tempStringList = configBufferList[i].defaultListValue;
 		}
 	}
-	
+
 	istringstream isst;
-	string tempString;
 	int tempInt;
 	list<string>::iterator it;
-	for(it = tempStringList.begin(); it != tempStringList.end(); it++) {
-		
+	for(it = tempStringList.begin(); it != tempStringList.end(); ++it) {
+
 		isst.str(*it);
 		isst >> tempInt;
 		tempIntList.push_back(tempInt);
@@ -524,14 +545,13 @@ void CleanerConfig::writeConfigInt(string varName, int varCont)
 {
 
 	size_t i;
-	string tempString;
 	ostringstream intToString;
 
-	for (i=0; i<configBufferList.size(); i++) {	
+	for (i=0; i<configBufferList.size(); i++) {
 
 		if (configBufferList[i].name == varName) {
 			intToString << varCont;
-			configBufferList[i].defaultValue = intToString.str();	
+			configBufferList[i].defaultValue = intToString.str();
 		}
 	}
 }
@@ -544,20 +564,19 @@ void CleanerConfig::writeConfigIntList(string varName, list<int> varCont)
 	ostringstream intToString;
 	list<string> stringList;
 
-	for (i=0; i<configBufferList.size(); i++) {	
+	for (i=0; i<configBufferList.size(); i++) {
 
 		if (configBufferList[i].name == varName) {
-			string tempString;
 			list<int>::iterator it;
-			for(it = varCont.begin(); it != varCont.end(); it++) {
-			
-				intToString << (*it);	
+			for(it = varCont.begin(); it != varCont.end(); ++it) {
+
+				intToString << (*it);
 				stringList.push_back(intToString.str());
 				intToString.str("");
 				intToString.clear();
 			}
-			
-			configBufferList[i].defaultListValue = stringList;	
+
+			configBufferList[i].defaultListValue = stringList;
 		}
 	}
 }
@@ -566,13 +585,12 @@ void CleanerConfig::writeConfigStringList(string varName, list<string> varCont)
 {
 
 	size_t i;
-	list<string> stringList;
 
-	for (i=0; i<configBufferList.size(); i++) {	
+	for (i=0; i<configBufferList.size(); i++) {
 
 		if (configBufferList[i].name == varName) {
-			
-			configBufferList[i].defaultListValue = varCont;	
+
+			configBufferList[i].defaultListValue = varCont;
 		}
 	}
 }
@@ -581,23 +599,30 @@ void CleanerConfig::writeConfigString(string varName, string varCont)
 {
 
 	size_t i;
-	for (i=0; i<configBufferList.size(); i++) {	
-		if (configBufferList[i].name == varName) { configBufferList[i].defaultValue = varCont; }
+	for (i=0; i<configBufferList.size(); i++) {
+		if (configBufferList[i].name == varName) {
+			configBufferList[i].defaultValue = varCont;
+		}
 	}
 
 }
-std::string CleanerConfig::stringToUtf8(const std::string &myString) {
+std::string CleanerConfig::stringToUtf8(const std::string &myString)
+{
 
 	QString tmpString = QString::fromStdString(myString);
 	std::string myUtf8String = tmpString.toUtf8().constData();
-	
+
 	return myUtf8String;
 }
 
-std::string CleanerConfig::stringFromUtf8(const std::string &myString) {
+std::string CleanerConfig::stringFromUtf8(const std::string &myString)
+{
 	QString tmpString = QString::fromUtf8(myString.c_str());
-	
+
 	return tmpString.toStdString();
 }
 
-std::string CleanerConfig::getDefaultLanguage() { return QLocale::system().name().toStdString(); }
+std::string CleanerConfig::getDefaultLanguage()
+{
+	return QLocale::system().name().toStdString();
+}
