@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 
 #include "thread.h"
@@ -25,7 +38,8 @@ class ThreadStarter
 {
 public:
 	ThreadStarter(Thread &thread) : m_thread(thread) {}
-	void operator()() {
+	void operator()()
+	{
 		m_thread.MainWrapper();
 	}
 
@@ -34,6 +48,7 @@ private:
 };
 
 Thread::Thread()
+	: m_isTerminatedSemaphore(0), m_shouldTerminateSemaphore(0)
 {
 }
 
@@ -48,22 +63,14 @@ Thread::Run()
 
 	// Create the boost thread object.
 	if (!m_threadObj.get()) {
-		// Initialise data structures within the context of the thread
-		// who runs/terminates this thread.
-		m_userReqTerminateLock.reset(new boost::timed_mutex::scoped_try_lock(m_shouldTerminateMutex));
-		m_threadStartBarrier.reset(new boost::barrier(2));
-
 		m_threadObj.reset(new boost::thread(ThreadStarter(*this)));
-		m_threadStartBarrier->wait();
 	}
 }
 
 void
 Thread::SignalTermination()
 {
-	// Unlock the shouldTerminateMutex.
-	if (m_userReqTerminateLock.get()) // cannot signal before calling Run
-		m_userReqTerminateLock->unlock();
+	m_shouldTerminateSemaphore.post();
 }
 
 bool
@@ -75,19 +82,17 @@ Thread::Join(unsigned msecTimeout)
 	bool tmpIsTerminated;
 	if (msecTimeout == THREAD_WAIT_INFINITE) {
 		// Wait infinitely.
-		boost::timed_mutex::scoped_lock lock(m_isTerminatedMutex);
+		m_isTerminatedSemaphore.wait();
 		tmpIsTerminated = true;
 	} else {
 		// Wait for the termination of the application code.
-		boost::defer_lock_t defer;
-		boost::timed_mutex::scoped_timed_lock lock(m_isTerminatedMutex, defer);
-		tmpIsTerminated = lock.timed_lock(boost::posix_time::millisec(msecTimeout));
+		tmpIsTerminated = m_isTerminatedSemaphore.timed_wait(boost::posix_time::microsec_clock::universal_time() + boost::posix_time::millisec(msecTimeout));
 	}
 
 	if (tmpIsTerminated) {
 		boost::mutex::scoped_lock lock(m_threadObjMutex);
 		// Wait for "real" termination of the thread.
-		if (m_threadObj.get()) {
+		if (m_threadObj) {
 			m_threadObj->join();
 			m_threadObj.reset();
 		}
@@ -105,18 +110,14 @@ Thread::Msleep(unsigned msecs)
 void
 Thread::MainWrapper()
 {
-	boost::timed_mutex::scoped_lock lock(m_isTerminatedMutex);
-	assert(m_threadStartBarrier.get());
-	m_threadStartBarrier->wait();
 	this->Main();
+	m_isTerminatedSemaphore.post();
 }
 
 bool
 Thread::ShouldTerminate() const
 {
-	boost::defer_lock_t defer;
-	boost::timed_mutex::scoped_try_lock lock(m_shouldTerminateMutex, defer);
-	return lock.try_lock();
+	return m_shouldTerminateSemaphore.try_wait();
 }
 
 bool
