@@ -64,19 +64,22 @@ public:
 
 	~gameLobbyDialogImpl();
 
-	void exec();
+	int exec();
 
-	ChatTools *getMyChat() {
+	ChatTools *getMyChat()
+	{
 		return myChat;
 	}
 
 	void setSession(boost::shared_ptr<Session> session);
-	boost::shared_ptr<Session> getSession() {
+	boost::shared_ptr<Session> getSession()
+	{
 		assert(mySession.get());
 		return mySession;
 	}
 
-	void setMyW ( gameTableImpl* theValue ) {
+	void setMyW ( gameTableImpl* theValue )
+	{
 		myW = theValue;
 	}
 
@@ -84,7 +87,6 @@ public slots:
 
 	void createGame();
 	void joinGame();
-	void joinAnyGame();
 	void gameSelected(const QModelIndex &);
 	void updateGameItem(QList <QStandardItem*>, unsigned gameId);
 	void addGame(unsigned gameId);
@@ -98,13 +100,16 @@ public slots:
 	void updateStats(ServerStats stats);
 	void refreshGameStats();
 	void refreshPlayerStats();
-	void setCurrentGameName ( const QString& theValue ) {
+	void setCurrentGameName ( const QString& theValue )
+	{
 		currentGameName = theValue;
 	}
-	QString getCurrentGameName() const {
+	QString getCurrentGameName() const
+	{
 		return currentGameName;
 	}
-	gameTableImpl* getMyW() const {
+	gameTableImpl* getMyW() const
+	{
 		return myW;
 	}
 	void checkPlayerQuantity();
@@ -131,7 +136,6 @@ public slots:
 	void showWaitStartGameMsgBox();
 	void hideWaitStartGameMsgBox();
 	void stopWaitStartGameMsgBoxTimer();
-	void joinAnyGameButtonRefresh();
 	void reject();
 	void closeEvent(QCloseEvent *event);
 	void accept();
@@ -151,6 +155,7 @@ public slots:
 	void chatInfoPlayerInvitation(unsigned gameId, unsigned playerIdWho, unsigned playerIdFrom);
 	void chatInfoPlayerRejectedInvitation(unsigned gameId, unsigned playerIdWho, DenyGameInvitationReason reason);
 	void putPlayerOnIgnoreList();
+	void removePlayerFromIgnoreList();
 	bool playerIsOnIgnoreList(unsigned playerid);
 	void searchForPlayerRegExpChanged();
 	void showAutoStartTimer();
@@ -162,6 +167,10 @@ public slots:
 	void reportBadGameName();
 	void adminActionCloseGame();
 	void adminActionTotalKickBan();
+	void addConnectedSpectator(unsigned spectatorId, QString spectatorName);
+	void removeSpectator(unsigned spectatorId, QString);
+	void gameAddSpectator(unsigned, unsigned);
+	void gameRemoveSpectator(unsigned, unsigned);
 
 private:
 
@@ -203,6 +212,7 @@ private:
 	QMenu *nickListContextMenu;
 	QAction *nickListInviteAction;
 	QAction *nickListIgnorePlayerAction;
+	QAction *nickListUnignorePlayerAction;
 	QMenu *nickListPlayerInfoSubMenu;
 	QMenu *nickListAdminSubMenu;
 	QAction *nickListAdminTotalKickBan;
