@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,11 +14,28 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #ifndef MYSLIDER_H
 #define MYSLIDER_H
 
 #include <QtGui>
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#endif
+
 /*
 * This QSlider Extension was sponsored by: AZEVEDO Filipe aka Nox P@sNox <pasnox@gmail.com>
 * http://pasnox.tuxfamily.org
@@ -31,15 +48,18 @@ class Slider : public QSlider
 
 public:
 	Slider( QWidget* parent = 0 )
-		: QSlider( parent ) {
+		: QSlider( parent )
+	{
 	}
 
 	Slider( Qt::Orientation orientation, QWidget* parent = 0 )
-		: QSlider( orientation, parent ) {
+		: QSlider( orientation, parent )
+	{
 	}
 
 protected:
-	int pixelPosToRangeValue(int pos) const { // getted from QSlider.cpp with little adapt
+	int pixelPosToRangeValue(int pos) const   // getted from QSlider.cpp with little adapt
+	{
 		QStyleOptionSlider opt;
 		initStyleOption(&opt);
 		QRect gr = style()->subControlRect(QStyle::CC_Slider, &opt, QStyle::SC_SliderGroove, this);
@@ -59,11 +79,13 @@ protected:
 											   sliderMax - sliderMin, opt.upsideDown);
 	}
 
-	int pick(const QPoint &pt) const { // getted from QSlider.cpp with little adapt
+	int pick(const QPoint &pt) const   // getted from QSlider.cpp with little adapt
+	{
 		return orientation() == Qt::Horizontal ? pt.x() : pt.y();
 	}
 
-	virtual void mousePressEvent( QMouseEvent* ev ) { // getted from QSlider.cpp with little adapt
+	virtual void mousePressEvent( QMouseEvent* ev )   // getted from QSlider.cpp with little adapt
+	{
 		if (maximum() == minimum() || (ev->buttons() ^ ev->button())) {
 			ev->ignore();
 			return;
