@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include "guiwrapper.h"
 #include "session.h"
@@ -328,6 +341,10 @@ void GuiWrapper::SignalNetClientStatsUpdate(const ServerStats &stats)
 {
 	myStartWindow->signalNetClientStatsUpdate(stats);
 }
+void GuiWrapper::SignalNetClientPingUpdate(unsigned minPing, unsigned avgPing, unsigned maxPing)
+{
+	myW->signalNetClientPingUpdate(minPing, avgPing, maxPing);
+}
 void GuiWrapper::SignalNetClientShowTimeoutDialog(NetTimeoutReason reason, unsigned remainingSec)
 {
 	myStartWindow->signalNetClientShowTimeoutDialog(reason, remainingSec);
@@ -351,6 +368,7 @@ void GuiWrapper::SignalNetClientPlayerJoined(unsigned playerId, const string &pl
 void GuiWrapper::SignalNetClientPlayerChanged(unsigned playerId, const string &newPlayerName)
 {
 	myStartWindow->signalNetClientPlayerChanged(playerId, QString::fromUtf8(newPlayerName.c_str()));
+	myW->signalRefreshSpectatorsDisplay();
 }
 void GuiWrapper::SignalNetClientPlayerLeft(unsigned playerId, const string &playerName, int removeReason)
 {
@@ -360,6 +378,23 @@ void GuiWrapper::SignalNetClientPlayerLeft(unsigned playerId, const string &play
 	if (!playerName.empty() && playerName[0] != '#' && myW->isVisible())
 		myGuiLog->signalLogPlayerLeftMsg(tmpName, removeReason == NTF_NET_REMOVED_KICKED);
 }
+void GuiWrapper::SignalNetClientSpectatorJoined(unsigned playerId, const string &playerName)
+{
+	myStartWindow->signalNetClientSpectatorJoined(playerId, QString::fromUtf8(playerName.c_str()));
+	myW->signalNetClientSpectatorJoined(playerId);
+	if (!playerName.empty() && playerName[0] != '#' && myW->isVisible()) {
+		QString tmpName(QString::fromUtf8(playerName.c_str()));
+		myGuiLog->signalLogSpectatorJoinedMsg(tmpName);
+	}
+}
+void GuiWrapper::SignalNetClientSpectatorLeft(unsigned playerId, const string &playerName, int removeReason)
+{
+	QString tmpName(QString::fromUtf8(playerName.c_str()));
+	myStartWindow->signalNetClientSpectatorLeft(playerId, tmpName);
+	myW->signalNetClientSpectatorLeft(playerId);
+	if (!playerName.empty() && playerName[0] != '#' && myW->isVisible())
+		myGuiLog->signalLogSpectatorLeftMsg(tmpName, removeReason == NTF_NET_REMOVED_KICKED);
+}
 void GuiWrapper::SignalNetClientNewGameAdmin(unsigned playerId, const string &playerName)
 {
 
@@ -392,6 +427,14 @@ void GuiWrapper::SignalNetClientGameListPlayerLeft(unsigned gameId, unsigned pla
 {
 	myStartWindow->signalNetClientGameListPlayerLeft(gameId, playerId);
 }
+void GuiWrapper::SignalNetClientGameListSpectatorJoined(unsigned gameId, unsigned playerId)
+{
+	myStartWindow->signalNetClientGameListSpectatorJoined(gameId, playerId);
+}
+void GuiWrapper::SignalNetClientGameListSpectatorLeft(unsigned gameId, unsigned playerId)
+{
+	myStartWindow->signalNetClientGameListSpectatorLeft(gameId, playerId);
+}
 void GuiWrapper::SignalNetClientGameStart(boost::shared_ptr<Game> game)
 {
 	myStartWindow->signalNetClientGameStart(game);
@@ -490,3 +533,4 @@ void GuiWrapper::SignalRejectedGameInvitation(unsigned gameId, unsigned playerId
 {
 	myStartWindow->signalRejectedGameInvitation(gameId, playerIdWho, reason);
 }
+
