@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include "newgamedialogimpl.h"
 #include "changecompleteblindsdialogimpl.h"
@@ -27,14 +40,14 @@ newGameDialogImpl::newGameDialogImpl(QMainWindow *parent, ConfigFile *c)
 	setWindowFlags(Qt::WindowSystemMenuHint | Qt::CustomizeWindowHint | Qt::Dialog);
 #endif
 	setupUi(this);
+	this->installEventFilter(this);
 
 	myChangeCompleteBlindsDialog = new changeCompleteBlindsDialogImpl;
-
 	connect( radioButton_changeBlindsSettings, SIGNAL( clicked(bool) ), this, SLOT( callChangeBlindsDialog(bool) ) );
 
 }
 
-void newGameDialogImpl::exec()
+int newGameDialogImpl::exec()
 {
 
 	spinBox_quantityPlayers->setValue(myConfig->readConfigInt("NumberOfPlayers"));
@@ -66,8 +79,10 @@ void newGameDialogImpl::exec()
 	myChangeCompleteBlindsDialog->spinBox_afterThisAlwaysRaiseValue->setValue(myConfig->readConfigInt("AfterMBAlwaysRaiseValue"));
 	myChangeCompleteBlindsDialog->radioButton_afterThisStayAtLastBlind->setChecked(myConfig->readConfigInt("AfterMBStayAtLastBlind"));
 
-	QDialog::exec();
-
+#ifdef ANDROID
+	this->showFullScreen();
+#endif
+	return QDialog::exec();
 }
 
 void newGameDialogImpl::callChangeBlindsDialog(bool show)
@@ -77,8 +92,38 @@ void newGameDialogImpl::callChangeBlindsDialog(bool show)
 		myChangeCompleteBlindsDialog->exec();
 		if(myChangeCompleteBlindsDialog->result() == QDialog::Accepted ) {}
 		else {
-			radioButton_useSavedBlindsSettings->setChecked(TRUE);
+			radioButton_useSavedBlindsSettings->setChecked(true);
 		}
 
 	}
 }
+
+bool newGameDialogImpl::eventFilter(QObject *obj, QEvent *event)
+{
+#ifdef ANDROID
+	QKeyEvent *keyEvent = static_cast<QKeyEvent*>(event);
+
+	//androi changes for return key behavior (hopefully useless from necessitas beta2)
+	if (event->type() == QEvent::KeyPress && keyEvent->key() == Qt::Key_Return) {
+		if(spinBox_gameSpeed->hasFocus()) {
+			spinBox_gameSpeed->clearFocus();
+		}
+		if(spinBox_quantityPlayers->hasFocus()) {
+			spinBox_quantityPlayers->clearFocus();
+		}
+		if(spinBox_startCash->hasFocus()) {
+			spinBox_startCash->clearFocus();
+		}
+		event->ignore();
+		return false;
+	} else if (event->type() == QEvent::KeyPress && keyEvent->key() == Qt::Key_Back) {
+		this->reject();
+		return true;
+	} else {
+		// pass the event on to the parent class
+		return QDialog::eventFilter(obj, event);
+	}
+#else
+	return QDialog::eventFilter(obj, event);
+#endif
+}
