@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,31 +14,45 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #include "manualblindsorderdialogimpl.h"
 #include "configfile.h"
+#include "mymessagebox.h"
 #include <iostream>
 
 
 manualBlindsOrderDialogImpl::manualBlindsOrderDialogImpl(QWidget *parent, ConfigFile *c)
-	: QDialog(parent), myConfig(c), settingsCorrect(TRUE)
+	: QDialog(parent), myConfig(c), settingsCorrect(true)
 {
 #ifdef __APPLE__
 	setWindowModality(Qt::ApplicationModal);
 	setWindowFlags(Qt::WindowSystemMenuHint | Qt::CustomizeWindowHint | Qt::Dialog);
 #endif
 	setupUi(this);
-
+#ifdef ANDROID
+	this->setWindowState(Qt::WindowFullScreen);
+#endif
 	connect( pushButton_add, SIGNAL( clicked() ), this, SLOT( addBlindValueToList() ) );
 	connect( pushButton_delete, SIGNAL( clicked() ), this, SLOT( removeBlindFromList() ) );
 
 }
 
-void manualBlindsOrderDialogImpl::exec()
+int manualBlindsOrderDialogImpl::exec()
 {
-
-
-	QDialog::exec();
+	return QDialog::exec();
 }
 
 
@@ -46,9 +60,9 @@ void manualBlindsOrderDialogImpl::addBlindValueToList()
 {
 
 	if(listWidget_blinds->count() == 30) {
-		QMessageBox::warning(this, tr("Manual Blinds Order"),
-							 tr("You cannot set more than 30 manual blinds."),
-							 QMessageBox::Close);
+		MyMessageBox::warning(this, tr("Manual Blinds Order"),
+							  tr("You cannot set more than 30 manual blinds."),
+							  QMessageBox::Close);
 	} else {
 		listWidget_blinds->addItem(QString::number(spinBox_input->value(),10));
 		sortBlindsList();
@@ -68,7 +82,7 @@ void manualBlindsOrderDialogImpl::sortBlindsList()
 	int i;
 	QList<int> tempIntList;
 	QStringList tempStringList;
-	bool ok = TRUE;
+	bool ok = true;
 
 	for(i=0; i<listWidget_blinds->count(); i++) {
 // 		std::cout << listWidget_blinds->item(i)->text().toInt(&ok,10) << "\n";
