@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 
 #include <net/serveradminbot.h>
@@ -36,6 +49,12 @@
 using namespace std;
 using namespace boost::filesystem;
 
+#ifdef BOOST_ASIO_HAS_STD_CHRONO
+using namespace std::chrono;
+#else
+using namespace boost::chrono;
+#endif
+
 ServerAdminBot::ServerAdminBot(boost::shared_ptr<boost::asio::io_service> ioService)
 	: m_notifyTimeoutMinutes(0), m_notifyIntervalMinutes(0), m_notifyCounter(0),
 	  m_notifyTimer(boost::posix_time::time_duration(0, 0, 0), boost::timers::portable::second_timer::manual_start),
@@ -259,17 +278,17 @@ ServerAdminBot::Run()
 	if (m_ircAdminThread) {
 		// Initialise the timers.
 		m_reconnectTimer.expires_from_now(
-			boost::posix_time::seconds(SERVER_RESTART_IRC_BOT_INTERVAL_SEC));
+			seconds(SERVER_RESTART_IRC_BOT_INTERVAL_SEC));
 		m_reconnectTimer.async_wait(
 			boost::bind(
 				&ServerAdminBot::ReconnectHandler, shared_from_this(), boost::asio::placeholders::error));
 		m_notifyLoopTimer.expires_from_now(
-			boost::posix_time::seconds(SERVER_NOTIFY_IRC_BOT_INTERVAL_SEC));
+			seconds(SERVER_NOTIFY_IRC_BOT_INTERVAL_SEC));
 		m_notifyLoopTimer.async_wait(
 			boost::bind(
 				&ServerAdminBot::NotifyLoop, shared_from_this(), boost::asio::placeholders::error));
 		m_checkFileTimer.expires_from_now(
-			boost::posix_time::seconds(SERVER_CHECK_IRC_BOT_INTERVAL_SEC));
+			seconds(SERVER_CHECK_IRC_BOT_INTERVAL_SEC));
 		m_checkFileTimer.async_wait(
 			boost::bind(
 				&ServerAdminBot::CheckFileHandler, shared_from_this(), boost::asio::placeholders::error));
@@ -285,7 +304,7 @@ ServerAdminBot::ReconnectHandler(const boost::system::error_code& ec)
 		Reconnect();
 
 		m_reconnectTimer.expires_from_now(
-			boost::posix_time::seconds(SERVER_RESTART_IRC_BOT_INTERVAL_SEC));
+			seconds(SERVER_RESTART_IRC_BOT_INTERVAL_SEC));
 		m_reconnectTimer.async_wait(
 			boost::bind(
 				&ServerAdminBot::ReconnectHandler, shared_from_this(), boost::asio::placeholders::error));
@@ -317,7 +336,7 @@ ServerAdminBot::CheckFileHandler(const boost::system::error_code& ec)
 			Reconnect();
 		}
 		m_checkFileTimer.expires_from_now(
-			boost::posix_time::seconds(SERVER_CHECK_IRC_BOT_INTERVAL_SEC));
+			seconds(SERVER_CHECK_IRC_BOT_INTERVAL_SEC));
 		m_checkFileTimer.async_wait(
 			boost::bind(
 				&ServerAdminBot::CheckFileHandler, shared_from_this(), boost::asio::placeholders::error));
@@ -373,7 +392,7 @@ ServerAdminBot::NotifyLoop(const boost::system::error_code& ec)
 			}
 		}
 		m_notifyLoopTimer.expires_from_now(
-			boost::posix_time::seconds(SERVER_NOTIFY_IRC_BOT_INTERVAL_SEC));
+			seconds(SERVER_NOTIFY_IRC_BOT_INTERVAL_SEC));
 		m_notifyLoopTimer.async_wait(
 			boost::bind(
 				&ServerAdminBot::NotifyLoop, shared_from_this(), boost::asio::placeholders::error));
