@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 /* Socket message definitions. */
 #ifndef _SOCKET_MSG_H_
@@ -48,6 +61,8 @@
 #define ERR_SOCK_TRANSFER_INVALID_URL	26
 #define ERR_SOCK_TRANSFER_SELECT_FAILED	27
 #define ERR_SOCK_TRANSFER_FAILED		28
+#define ERR_SOCK_CONNECT_IPV6_FAILED	29
+#define ERR_SOCK_CONNECT_IPV6_TIMEOUT	30
 // The following errors are game errors.
 #define ERR_NET_VERSION_NOT_SUPPORTED	101
 #define ERR_NET_SERVER_MAINTENANCE		102
@@ -103,6 +118,7 @@
 #define NTF_NET_REMOVED_KICKED			205
 #define NTF_NET_REMOVED_TIMEOUT			206
 #define NTF_NET_REMOVED_START_FAILED	207
+#define NTF_NET_REMOVED_GAME_CLOSED		208
 
 // Notifications - join failed
 #define NTF_NET_JOIN_GAME_INVALID		210
@@ -116,10 +132,11 @@
 #define NTF_NET_JOIN_INVALID_SETTINGS	218
 #define NTF_NET_JOIN_IP_BLOCKED			219
 #define NTF_NET_JOIN_REJOIN_FAILED		220
+#define NTF_NET_JOIN_NO_SPECTATORS		221
 
 // Notifications - version
-#define NTF_NET_NEW_RELEASE_AVAILABLE	221
-#define NTF_NET_OUTDATED_BETA			222
+#define NTF_NET_NEW_RELEASE_AVAILABLE	231
+#define NTF_NET_OUTDATED_BETA			232
 
 // This is an internal message which is not reported.
 #define MSG_SOCK_INTERNAL_PENDING		0
@@ -154,9 +171,19 @@
 #define MSG_NET_LIMIT_GAME				MSG_NET_GAME_SERVER_END
 
 // Some messages which are displayed in the GUI
-#define MSG_NET_AVATAR_REPORT_ACCEPTED	MSG_NET_LIMIT_GAME + 1
-#define MSG_NET_AVATAR_REPORT_DUP		MSG_NET_LIMIT_GAME + 2
-#define MSG_NET_AVATAR_REPORT_REJECTED	MSG_NET_LIMIT_GAME + 3
+#define MSG_NET_AVATAR_REPORT_ACCEPTED		MSG_NET_LIMIT_GAME + 1
+#define MSG_NET_AVATAR_REPORT_DUP			MSG_NET_LIMIT_GAME + 2
+#define MSG_NET_AVATAR_REPORT_REJECTED		MSG_NET_LIMIT_GAME + 3
+#define MSG_NET_GAMENAME_REPORT_ACCEPTED	MSG_NET_LIMIT_GAME + 4
+#define MSG_NET_GAMENAME_REPORT_DUP			MSG_NET_LIMIT_GAME + 5
+#define MSG_NET_GAMENAME_REPORT_REJECTED	MSG_NET_LIMIT_GAME + 6
+#define MSG_NET_ADMIN_REMOVE_GAME_ACCEPTED	MSG_NET_LIMIT_GAME + 7
+#define MSG_NET_ADMIN_REMOVE_GAME_REJECTED	MSG_NET_LIMIT_GAME + 8
+#define MSG_NET_ADMIN_BAN_PLAYER_ACCEPTED	MSG_NET_LIMIT_GAME + 9
+#define MSG_NET_ADMIN_BAN_PLAYER_PENDING	MSG_NET_LIMIT_GAME + 10
+#define MSG_NET_ADMIN_BAN_PLAYER_NODB		MSG_NET_LIMIT_GAME + 11
+#define MSG_NET_ADMIN_BAN_PLAYER_DBERROR	MSG_NET_LIMIT_GAME + 12
+#define MSG_NET_ADMIN_BAN_PLAYER_REJECTED	MSG_NET_LIMIT_GAME + 13
 
 #endif
 
